{ FoxClone
  Copyright (C) 2021 Andy Hardwick
  This source is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free
  Software Foundation; either version 2 of the License, or (at your option)
  any later version.
  This code is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  details.
  A copy of the GNU General Public License is available on the World Wide Web
  at <http://www.gnu.org/copyleft/gpl.html>. You can also obtain it by writing
  to the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  Boston, MA 02110-1335, USA.
}
{-------------------------------------------------------------------------------
UNIT - IL8NSTRINGS

Originally conceived as the repository for all text strings displayed in foxclone. Aim was to
facilitate translation into other languages.

//https://wiki.freepascal.org/Step-by-step_instructions_for_creating_multi-language_applications

Then realised that in other languages the output of terminal commands like parted and sfdisk are
also translated. The various methods parsing these commands assume english and would fail. The
search phrases are not in this unit and would require some effort to extract.

Multi-language on hold for the time being.

Note - the date showing in the main foxclone window is set in this unit.


V1.0 - 21 Feb 2021
-------------------------------------------------------------------------------}

unit il8nstrings;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, utilities;
resourcestring
  rVerStr = 'Version'; //Version label on main form
  rVerDateStr = '01 May 2024'; //Version label on main form
  //tab titles set in main form constructor
  rBackTabStr = 'Backup';
  rRestTabStr = 'Restore';
  rCloneTabStr = 'Clone';
  rVerifyTabStr = 'Verify';
  rSetTabStr = 'Settings';
  rAboutTabStr = 'About';
  //used in message dialogs
  rWarningStr = 'Warning';
  rErrorStr = 'Error';
  rMountFailStr = 'Unable to mount'; //message dialog in function mount
  rMkDirFailStr = 'Unable to create folder'; //message dialog in function mkdir
  rUmountFailStr = 'Unable to un mount'; //message dialog in function umount
  rRmDirFailStr = 'Unable to remove folder'; //message dialog in function rmdir

  //startup form message dialog
  rStartCaptionStr = 'Cannot close';
  rStartMsgStr = 'Cannot close until the system has been read';

  //hint shown on hover over the info image on box 2
  rInfoImg2HintStr = 'Default is ALL' + LF + 'Enable "advanced" on the settings tab to select individual partitions';
  rPartTableStr = 'Partition table'; //used in drive checklist box strings
  //drive hint str titles
  rMountptStr = 'Mount point';
  rModelStr = 'Model';
  rSerialStr = 'Serial number';
  rSizeStr = 'Size';
  rPartitionStr = 'Partitions';

  //backup tab
  rBackTitleStr = 'Backup Drive to Image Files';  //main title
  rBackBox1Str = '1 - Drive to Backup:'; //Box1 title
  rBackBox2Str = '2 - Partition(s) to Backup:'; //Box2 title
  rBackBox3Str = '3 - Destination Drive:'; //Box3 title
  rBackBox4Str = '4 - Destination Partition:'; //Box3 title

  //Restore tab
  rRestTitleStr = 'Restore Drive from Image Files';
  rRestBox1Str = '1 - Source Drive:';
  rRestBox2Str = '2 - Partition containing the backup file:';
  rRestBox3Str = '3 - Contents of Backup:';
  rRestBox4Str = '4 - Destination Drive:';
  rRestDateStr = 'Backup date';
  rTimeNowStr = 'Time now';
  rNoteBtnStr = 'View Note';

  rQuitStr = 'Quit'; //Caption in quit button
  rNextStr = 'Save to File'; //Caption in next button

  //clone tab
  rCloneComboStr1 = 'Drive to Drive'; //combo drop down first item
  rCloneComboStr2 = 'Backup file to Drive'; //combo drop down second item
  rCloneComboHint = 'A direct copy drive to drive,' + LF + 'or from a backup file to drive';
  rCloneBox2Str = '2 - Target Drive:';
  rCloneBox4Str = '4 - Target Drive:';

  //verify tab
  rVerifyTitleStr = 'Verify Backup Files';
  rVerifyBox4Str = 'Select backup files to verify';

  //settings tab
  rSettingTitle = 'Settings';
  rCompFiles = 'Compress backup files';
  rBackupSettings = 'Backup Settings';
  rSplitFiles = 'Split backup files';
  rUserSettings = 'User Settings';
  rPartSelect = 'Enable partition selection';
  rFontSize = 'Font size';
  rTroubleShoot = 'Troubleshooting';
  rEnableDebug = 'Enable debugging';
  rDebugInfo = 'Debugging information will be saved in ';

  //startup form
  rReadSystem = 'Reading System'; //title on startup form
  rFindDrives = 'Finding drives...';
  rReadDrives = 'Reading drives...';
  rReadOS = 'Searching for OS';
  rFindParts = 'Finding partitions...';
  rReadParts = 'Reading Partitions...';
  rDriveStr = 'Drives';
  rOpSysStr = 'Operating systems';
  rCompleteStr = 'Complete';
  //partitions = same as rPartitionStr

  //drive hint strings
  rnotHintStr = 'Drives excluded';
  rnotHintBootStr = 'is the boot drive';
  rnotHintLoopStr = 'has no partition table';
  rnotHintBlankStr = 'is blank or has an unknown partition table type';
  rnotHintSourceStr = 'is the drive to be backed up';
  rnotHintSource2Str = 'is the source drive';
  //partition list strings
  rUsedStr = 'used'; //as in 'used space'
  rUsedUCStr = 'Used';
  rEFIpartStr = 'EFI system partition';
  rFlagsStr = 'Flags'; //flags set on a partition such as boot or esp

  //partition hint strings
  rFileSystemStr = 'Filesystem'; //as in ext4 or ntfs
  rBlockStr = 'blocks';
  rLabelStr = 'Label'; //as in a label on a filesystem
  rNameStr = 'Name'; //as in a partition name on a GPT drive
  rTypeStr = 'Type'; //as in partition table type, e.g. msdos gpt
  rExtendedStr = 'An extended partition cannot be selected.';
  rEFIpartMSgStr = 'An EFI (boot) partition cannot be selected.';
  rSwapMsgStr = 'An swap partition cannot be selected.';
  rAutoBackStr = 'It is automatically backed up.';

  //system error messages
  rSysErrorCaption = 'Internal Error';
  rCloseMsgStr = 'foxlone will now close. Read the section in the user guide on troubleshooting.';
  rSysErrMsg1 = 'Could not find the drive selected for backup:';
  rSysErrMsg2 = 'Could not find the partition selected for backup:';
  rSysErrMsg3 = 'Drive selected for backup in box1 (acSource) could not be found for the partition hint string.';
  rSysErrMsg4 = 'Partition could not be found for the partition hint string.';
  rSysErrMsg5 = 'Could not find the drive selected as the destination for a backup:';
  rSysErrMsg6 = 'Could not find the drive selected as the destination (acTarget) for a backup:';
  rSysErrMsg7 = 'Drive selected as the destination in box3 (acTarget) could not be found for the partition hint string.';
  rSysErrMsg8 = 'Checking free space: unable to find the drive selected for backup (acSource).';
  rSysErrMsg9 = 'Checking free space: unable to find the drive selected as the backup destination (acTarget).';
  rSysErrMsg10 = 'Checking free space: unable to find the partition selected as the backup destination.';
  rSysErrMsg11 = 'Could not find the partition selected as the destination:';
  rSysErrMsg12 = 'Could not find the drive selected for restore:';
  rSysErrMsg13 = 'Drive selected for restore in box1 could not be found for the partition hint string.';
  rSysErrMsg14 = 'Could not find the drive containing the backup (acSource) for a restore.';
  rSysErrMsg15 = 'Could not find the partition containing the backup:';
  rSysErrMsg16 = 'Could not mount the partition containing the backup file:';
  rSysErrMsg17 = 'Could not find partition, mismatch between sfdisk and backup files:';
  rSysErrMsg18 = 'Could not find the drive selected as the destination (acTarget) for a restore:';
  rSysErrMsg18a = 'Unable to check if the partition table has changed.';
  rSysErrMsg19 = 'Could not find the drive selected for clone:';
  rSysErrMsg20 = 'Could not find the drive containing the backup (acSource) for a clone.';
  rSysErrMsg21 = 'Target drive for restore could not be found for the partition hint string.';
  rSysErrMsg22 = 'Target drive for clone from backup could not be found.';
  rSysErrMsg23 = 'Could not find the partition selected in the backup file.';
  rSysErrMsg24 = 'Could not find the target drive for clone:';
  rSysErrMsg25 = 'Cound not find the target drive for backup - fat32 check.';
  rSysErrMsg26 = 'Cound not find the target partition for backup - fat32 check.';

  //message when partition edit is not enabled
  rPartEditCapStr = 'Partition selection not enabled';
  rPartEditStr = 'All partitions are selected by default. To change this, enable partition selection on the settings tab to select/deselect individual partions.';

  //messages on available space for backup
  rCompFitStr = 'Compression is enabled and the backup may fit on the selected partition:';
  rSpaceReqdStr = 'Space required = ';
  rCompReqdStr = 'Space required with compression typically = ';
  rSpaceAvailStr = 'Space available on [destination] = ';
  rProceedStr = 'Okay to proceed or Cancel to select another drive and partition.';
  rNoSpaceStr = 'Not enough space on [destination], choose another partition or drive.';

  //restore open file title
  rRestFileTitleStr = 'Open backup file';

  //restore error messages
  //selecting a backup on a partition selected from the devices pane with opendialog
  rWrongPartTitle = 'Wrong Partition';
  rWrongPartMsg1 = 'The selected backup file';
  rWrongPartMsg2 = 'Is not on';
  rWrongPartMsg3 = 'Do not select files from the places pane.';

  //check on sfdisk for unit
  rBlkErrTitle = 'Block Adjustment Error';
  rBlkErrMsg1 = 'Unit size reported in sfdisk is not sectors';
  rBlkErrMsg2 = 'Reported block sizes will be incorrect.';

  //file not found errors
  rFileNotFoundStr = 'Cannot find the file';

  //drive not found errors
  rDriveNotFoundStr = 'Drive not found';
  rDriveFailStr = 'Failed to find the drive the backup was taken from';

  //label below box4 on the restore tab
  rExistStr ='Existing partitions on the destination drive';

  //the mountpoint for the drive has changed since the backup
  rChangeMtTitleStr = 'Mount point change';
  rChangeMtStr = 'Drive [drive] was on [oldmount] when the backup was taken, it is now on [newmount].';
  rChangeMtStr2 = 'Continue with restore to [newmount]?';

  //noteform
  rNoteTitle = 'Backup Note';
  rNoteSave = 'Save';
  rNoteCancel = 'Cancel';
  rClose = 'Close';

  //Restore Box3
  rRestPTable = 'Restore partition table';

  //checking the partition table on a restore
  rChkPTchangeStr = 'The partition table has changed since the backup';
  rChkPTbackStr = 'The backup contains [partitions] partitions';
  rChkPTcurrentStr = 'The current drive has [partitions] partitions';
  rChkPTreplaceStr = 'The partition table will be restored.';
  rChkPTCurrentDriveStr = 'Current drive';

  //partition not backed up cannot be restored
  rNoBackupStr = 'Not in backup';
  rNoBackupPartStr = '[partition] was not backed up when the backup was taken, it cannot be restored.';
  //partition is an EFI part and must be restored
  rEFItitle = 'EFI Partition';
  rEFImsg1 = '[partition] is the EFI partition';
  rEFImsg2 = 'An EFI partition is always restored when the partition table is restored';
  //partition is an extended partition and follows the partition table
  rExttitle = 'Extended Partition';
  rExtMsg = 'An extended partition is part of the partition table.';

  //clone drive to drive will not fit
  rNoCloneTitleStr = 'Not enough space';
  rNoCloneDriveStr = '[Sdrive] will not clone to [Tdrive]';
  rNoCloneSourceStr = 'Last partition ends at [sblocks] on [Sdrive]';
  rNoCloneTargetStr = 'Target drive size ';
  rNoCloneMsgStr = 'Shrink the partitions on [Sdrive] with gparted and try again.';
  rNoCloneBackupStr = 'The backup will not clone to [Tdrive]';
  rNoCloneBackSizeStr = 'Last partition in the backup ends at ';
  rNoCloneMsg2Str = 'Shrink the partitions on the source drive, do another backup and try again.';

  //clone from file
  rCloneMsgTitle = 'Incomplete backup';
  rCloneMsgStr = 'The selected partition is not in the backup.';
  rCloneFtitleStr = 'Clone from file'; //for progress form on a clone from file

  //verify tab strings
  rNoVerifyStr = 'Verification is not supported.';
  rSwapStr = 'Swap partition';
  rUnsupportedStr = 'Filesystem not supported';
  rNoVerifyBackupStr = '[partition] was not backed up when the backup was taken.';
  rUnknownStr = '[partition] constains a [fs] filesystem.';

  //about tab strings
  rAboutStr = 'An image backup, restore and clone tool. Foxclone is a front end for partclone written in Pascal using the lazarus IDE.';
  rCopyRightStr = 'Copyright © 2019 – 2024: Andy Hardwick, Larry Hale (1945 – 2022).';
  rImageStr = 'Images ShiipArt and gaga.vastard.';
  rLicenceStr1 = 'This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.';
  rLicenceStr2 = 'This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.';
  rLicenceStr3 = 'See the GNU General Public License for more details http://www.gnu.org/licenses/.';

  //backup - save dialog selecting a different partition from the places pane = error
  rSaveTitleStr = 'Destination changed';
  rSaveMsgStr1 = 'Destination drive/partition must be the same as selected in the main window.';
  rSaveMsgStr2 = 'You cannot select a volume from Places.';

  //confform, note rNoteCancel = 'Cancel';
  rOKstr = 'Ok';
  rDestinationStr = 'Destination';
  rFileStr = 'File';
  rSourceStr = 'Source';
  rConfirmBackupStr = 'Confirm Backup';
  rConfirmRestoreStr = 'Confirm Restore';
  rFromFileStr = 'From file';
  rToDriveStr = 'To drive';
  rConfirmCloneStr = 'Confirm Clone';
  rCloneWarnStr = 'WARNING - the target drive will be overwritten!';
  rTargetStr = 'Target';
  rConfirmCloneFileStr = 'Confirm Clone from Backup File';

  //progress form
  rFinishStr = 'Finish';
  rAddNoteStr = 'Add Note';
  rEditNoteStr = 'Edit Note';
  rViewLogStr = 'View Log';
  rCloseStr = 'Cannot close';
  rPartCloneRunStr = 'Partclone is running';
  rLogBtnStr = 'View Log';

  //grub backup and restore
  rGrubErrorStr = 'Failed to copy grub:';
  //sfdisk backup and restore
  rSfdiskErrorStr = 'Failed to copy partition table:';

  //debug
  rDebugTitleStr = 'Debug';
  rDebugErrStr = 'Cannot find home folder:';
  rDebugErrStr2 = 'Cannot enable debug.';

  //partclone error message - the error message can push the ok button below the message box
  rPartCloneMsgStr = 'If the OK button is not visible, increase the size of the message box.';
  //backup strings
  rBackupTitleStr = 'Backing up ';
  rBackFinishStr = 'Backup complete';
  //partclone cancel msg
  rPartCloneCancelStr = 'Any backup files will need to be manually deleted.';
  rPartCloneCancelVStr = 'Any *.chk files in the backup folder can be manually deleted.';
  //partition re-read error message
  rPtableErrorStr = 'Error writing partition table to ';
  //swap restore error
  rSwapErrStr = 'Error restoring the swap partition';

  //Restore complete
  rRestFinishStr = 'Restore complete';
  //Clone from file complete
  rCloneFfinStr = 'Clone from file complete';
  //clone drive to drive
  rCloneTitleStr = 'Clone Drive to Drive';
  rClonePTable = 'Clone partition table';
  rCloneFinStr = 'Clone drive to drive complete';

  //verification
  rVerifyFinStr = 'Verify complete';
  rVerifyLogStr = ' backup image verified ';

  //dev/mapper error
  rVirtTitleStr = 'Virtual device';
  rVirtDevStr = 'Virtual device found and will be ignored:';
  //rVirtFsckStr = 'This may be caused by a corrupted filesystem, check the partition with fsck.';
  //failed to get used blocks, could be caused by /dev/mapper error
  rUsedErrStr = 'Used blocks cannot be determined for ';
  rUsedErrStr2 = 'Used blocks will be set to partition size.';
  rUsedErrStr3 = '. The partition may be encrypted, using LVM or a zfs pool.';

  //gparted message
  rGpartedTitle = 'Gparted';
  rGpartedError1 = 'gparted is running. This will cause errors writing the partition table.';
  rGpartedError2 = 'Close gparted and try again.';

implementation


end.

